@@ -25,11 +25,11 @@ class GlofasForecast(Dataset):
 
     dataset = "glofas_forecast"
 
-    def __init__(self):
-        self.parser = Parser()
+    temporal_range = [2019,2021]
 
-    # @normalize_args(variable=["river_discharge_in_the_last_24_hours"])
-    def _load(self, system_version, product_type, model, variable, period, leadtime):
+    def __init__(self, system_version, product_type, model, variable, period, leadtime):
+        
+        self.parser = Parser(temporal_range)
 
         years, months, days = self.parser.period(period)
 
