@@ -25,11 +25,11 @@ class GlofasHistorical(Dataset):
 
     dataset = None
 
-    def __init__(self):
-        self.parser = Parser()
+    temporal_range = [1979,2021]
 
-
-    def _load(self, system_version, product_type, model, variable, period):
+    def __init__(self, system_version, product_type, model, variable, period):
+        
+        self.parser = Parser(temporal_range)
 
         years, months, days = self.parser.period(period)
 
